The RepliCrisis Shiny app is an interactive game based on the process for
evaluating replication studies presented in Hoijtink et. al. (2009). Users can
conduct original studies, process the results, and attempt to replicate the
studies while adjusting parameters to see how changes affect the outcome.
Usage
RepliCrisis()
Arguments
Value
An interactive Shiny app.
References
Hoijtink, H., Mulder, J., van Lissa, C., & Gu, X. (2019). A tutorial on
testing hypotheses using the Bayes factor. Psychological methods, 24(5),
539–556. doi:10.1037/met0000201